==> ejc-zdsmaterialb-impl-3.0.0-20251028.064012-68-sources.jar: com/ejianc/business/zdsmaterial/material/controller/MatFeeApplyErpController.java <==
package com.ejianc.business.zdsmaterial.material.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.ejianc.business.zdsmaterial.cons.PlanConstant;
import com.ejianc.business.zdsmaterial.erp.service.IContractService;
import com.ejianc.business.zdsmaterial.material.bean.MatFeeApplyDetailEntity;
import com.ejianc.business.zdsmaterial.material.bean.MatFeeApplyFileDetailEntity;
import com.ejianc.business.zdsmaterial.material.service.IMatFeeApplyDetailService;
import com.ejianc.business.zdsmaterial.material.service.IMatFeeApplyFileDetailService;
import com.ejianc.business.zdsmaterial.material.service.IMatFeeApplyService;
import com.ejianc.business.zdssupplier.material.api.IMatSupplierApi;
import com.ejianc.business.zdssupplier.material.vo.MatSupplierVO;
import com.ejianc.foundation.file.api.IAttachmentApi;
import com.ejianc.foundation.file.vo.AttachmentVO;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.vo.EmployeeVO;
import com.ejianc.foundation.share.api.IProjectPoolApi;
import com.ejianc.foundation.share.vo.ProjectPoolSetVO;
import com.ejianc.framework.core.kit.time.DateFormatUtil;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author CJ
 * @Description:
 * @date 2024/5/20 19:06
 */
@RestController
@RequestMapping("matFeeApply/erp")
public class MatFeeApplyErpController {

    Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IProjectPoolApi projectPoolApi;

    @Autowired
    private IEmployeeApi employeeApi;

    @Autowired
    private IAttachmentApi attachmentApi;

    @Autowired
    private IMatSupplierApi matSupplierApi;

    @Value("${common.env.base-host}")
    private String BASE_HOST;

    @Autowired
    private IMatFeeApplyService service;

    @Autowired
    private IMatFeeApplyDetailService detailService;

    @Autowired
    private IMatFeeApplyFileDetailService detailFileService;

    @PostMapping(value = "/pageList")
    public CommonResponse<JSONObject> pageSyncList(@RequestBody JSONObject param) {
        JSONObject resp = new JSONObject();

        logger.info("ERP查询采购费用申请参数：{}", JSONObject.toJSONString(param, SerializerFeature.PrettyFormat));
        Integer pageSize = null != param && null != param.getInteger("PageSize") ? param.getInteger("PageSize") : 10;
        Integer pageNum = null != param && null != param.getInteger("PageNum") ? param.getInteger("PageNum") : 1;
        String BeginDateTime = null != param && null != param.getString("BeginDateTime") ? param.getString("BeginDateTime") : null;
        String EndDateTime = null != param && null != param.getString("EndDateTime") ? param.getString("EndDateTime") : null;

        Map<String, Object> queryParam = new HashMap<>();
        if(StringUtils.isNotBlank(BeginDateTime)) {
            queryParam.put("beginDateTime", BeginDateTime);
        }
        if(StringUtils.isNotBlank(EndDateTime)) {
            queryParam.put("endDateTime", EndDateTime);
        }

        int count = service.pageCount(queryParam);
        resp.put("total", count);
        resp.put("pageSize", pageSize);
        resp.put("pageNum", pageNum);

        if (count == 0) {
            resp.put("records", new ArrayList<>());
            return CommonResponse.success("查询成功！", resp);
        }

        Integer startLine = pageNum - 1 < 0 ? pageSize : (pageNum - 1) * pageSize;
        queryParam.put("startLine", startLine);
        queryParam.put("pageSize", pageSize);

        List<JSONObject> pageList = service.pageList(queryParam);
        List<Long> projectIds = new ArrayList<>();
        List<Long> pIds = new ArrayList<>();
        List<Long> supplierIds = new ArrayList<>();
        List<String> empCodes = new ArrayList<>();
        pageList.stream().forEach(item -> {
            if (!projectIds.contains(item.getLong("projectId"))) {
                projectIds.add(item.getLong("projectId"));
            }
            if (!pIds.contains(item.getLong("YQL_SID"))) {
                pIds.add(item.getLong("YQL_SID"));
            }
            if (!supplierIds.contains(item.getLong("supplierId"))) {
                supplierIds.add(item.getLong("supplierId"));
            }
            if(StringUtils.isNotBlank(item.getString("ApprHumanCode")) && !empCodes.contains(item.getString("ApprHumanCode"))) {
                empCodes.add(item.getString("ApprHumanCode"));
            }
        });

        //查询项目信息
        CommonResponse<JSONArray> projectResp = projectPoolApi.queryProjectByIds(projectIds);
        if (!projectResp.isSuccess()) {
            logger.error("分包结算查询失败，根据项目Id列表-{}查询项目信息失败，{}", JSONObject.toJSONString(projectIds),
                    JSONObject.toJSONString(projectResp, SerializerFeature.PrettyFormat));
            return CommonResponse.error("查询失败，获取项目信息失败！");
        }

        Map<Long, String> projectSidMap = new HashMap<>();
        List<ProjectPoolSetVO> projectList = JSONArray.parseArray(JSONObject.toJSONString(projectResp.getData()), ProjectPoolSetVO.class);
        if (CollectionUtils.isNotEmpty(projectList)) {
            projectSidMap.putAll(projectList.stream().collect(Collectors.toMap(ProjectPoolSetVO::getId, ProjectPoolSetVO::getSourceId)));
        }

        //查询供应商信息
        Map<Long, MatSupplierVO> supplierMap = new HashMap<>();
        CommonResponse<List<MatSupplierVO>> supplierResp = matSupplierApi.getAllByIds(supplierIds);
        if (!supplierResp.isSuccess()) {
            logger.error("分包结算查询失败，根据供应商列表-{}查询人员信息失败，{}", JSONObject.toJSONString(supplierIds),
                    JSONObject.toJSONString(supplierResp, SerializerFeature.PrettyFormat));
            return CommonResponse.error("查询失败，获取供应商信息失败！");
        }
        supplierMap.putAll(supplierResp.getData().stream().collect(Collectors.toMap(MatSupplierVO::getId, Function.identity())));

        //查询人员信息
        Map<String, EmployeeVO> empMap = new HashMap<>();
        CommonResponse<List<EmployeeVO>> empResp = employeeApi.getAllByEmployeeCodes(empCodes);
        if(!empResp.isSuccess()) {
            logger.error("分包结算查询失败，根据人员工号列表-{}查询人员信息失败，{}", JSONObject.toJSONString(empCodes),
                    JSONObject.toJSONString(empResp, SerializerFeature.PrettyFormat));
            return CommonResponse.error("查询失败，获取人员信息失败！");
        }
        List<EmployeeVO> empList = empResp.getData();
        if(CollectionUtils.isNotEmpty(empList)) {
            empMap.putAll(empList.stream().collect(Collectors.toMap(EmployeeVO::getCode, Function.identity())));
        }

        //查询费用子表
        Map<Long, List<MatFeeApplyDetailEntity>> subDetailMap = detailService.getAllBySettleIds(pIds);

        //查询附件信息
        Map<Long, List<MatFeeApplyFileDetailEntity>> subFileMap = detailFileService.getAllBySettleIds(pIds);
        List<Long> fileIds = subFileMap.values().stream().flatMap(List::stream).map(MatFeeApplyFileDetailEntity::getAttachmentId).collect(Collectors.toList());
        CommonResponse<List<AttachmentVO>> attachResp = attachmentApi.queryAllByIds(fileIds);
        if(!attachResp.isSuccess()) {
            logger.error("根据sourceId列表-{}查询对应附件信息失败，", JSONObject.toJSONString(fileIds),
                    JSONObject.toJSONString(attachResp, SerializerFeature.PrettyFormat));
            return CommonResponse.error("查询失败，获取子表附件信息失败！");
        }

        List<AttachmentVO> fileData = attachResp.getData();
        Map<Long, AttachmentVO> fileMap = new HashMap<>();
        for (AttachmentVO vo: fileData){
            fileMap.put(vo.getId(), vo);
        }

        EmployeeVO emp = null;
        ProjectPoolSetVO project = null;
        MatSupplierVO supplier = null;
        AttachmentVO attach = null;
        for(JSONObject settle : pageList) {
            //获取项目信息
            settle.put("Account_Project_Sid", projectSidMap.get(settle.getLong("projectId")));
            settle.remove("projectId");
            //供应商信息
            supplier = supplierMap.get(settle.getLong("supplierId"));
            settle.put("Company_Sid", supplier.getThirdSourceId());
            settle.put("Company_Name", supplier.getName());
            settle.remove("supplierId");

            //获取审核人信息
            emp = empMap.get(settle.getString("ApprHumanCode"));
            settle.put("ApprHuman_sid", emp.getSourceId());
            settle.put("ApprHuman", emp.getName());

            //审核日期
            settle.put("ApprDate", DateFormatUtil.formatDate("yyyy-MM-dd", settle.getDate("ApprDate"))); //审核时间

            //子表信息
            JSONArray subDetailArr = new JSONArray();
            settle.put("SubDetailList", subDetailArr);
            if(null != subDetailMap.get(settle.getLong("YQL_SID"))) {
                JSONObject detailJson = null;
                for(MatFeeApplyDetailEntity detail : subDetailMap.get(settle.getLong("YQL_SID"))) {
                    detailJson = new JSONObject();
                    detailJson.put("ContractID", detail.getDetailContractCode()); //合同编码
                    detailJson.put("OrderCode", detail.getDetailOrderCode()); //订单编号
                    detailJson.put("Contract_Type", detail.getContractType()); //合同类型
                    detailJson.put("Contract_Flag", detail.getDetailPriceType()); //合同标识
                    detailJson.put("PaymentStyle", null != detail.getPaymentTypeId() ? PlanConstant.MAT_FEE_PATY_TYPE.get(detail.getPaymentTypeId().toString()) : ""); //合同标识
                    detailJson.put("ApplyMoney", detail.getApplyMny().toPlainString()); //本次申请金额
                    detailJson.put("ApplyPercentage", detail.getApplyScale().toPlainString()); //本次申请比例
                    detailJson.put("YQL_SID", detail.getId()); //本次申请比例

                    subDetailArr.add(detailJson);
                }
            }


            JSONArray subFileArr = new JSONArray();
            settle.put("ArchivesList", subFileArr);
            if(null != subFileMap.get(settle.getLong("YQL_SID"))) {
                JSONObject subF = null;
                for(MatFeeApplyFileDetailEntity scd : subFileMap.get(settle.getLong("YQL_SID"))) {
                    subF = new JSONObject();
                    attach = fileMap.get(scd.getAttachmentId());
                    if(null != attach) {
                        subF.put("Attach_Name", scd.getAttachmentName() + (scd.getAttachmentName().indexOf(".") < 0 ? attach.getFileName().substring(attach.getFileName().indexOf(".")) : "")); //附件名称
                        subF.put("Attach_Extension", attach.getFileName().substring(attach.getFileName().indexOf("."))); //附件扩展名
                        subF.put("Attach_Type", attach.getFileName().substring(attach.getFileName().indexOf(".")+1)); //附件类型
                        subF.put("AttachBase64", BASE_HOST + "filepreview/" + attach.getFilePath()); //附件类型
                        subF.put("YQL_SID", scd.getId()); //益企联主
                    }
                    subFileArr.add(subF);
                }
            }
        }

        resp.put("records", pageList);

        return CommonResponse.success("查询成功！", resp);
    }


}

==> ejc-zdsmaterialb-impl-3.0.0-20251128.064043-96-sources.jar: com/ejianc/business/zdsmaterial/material/controller/MatFeeApplyErpController.java <==
package com.ejianc.business.zdsmaterial.material.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.ejianc.business.zdsmaterial.cons.PlanConstant;
import com.ejianc.business.zdsmaterial.material.bean.MatFeeApplyDetailEntity;
import com.ejianc.business.zdsmaterial.material.bean.MatFeeApplyFileDetailEntity;
import com.ejianc.business.zdsmaterial.material.service.IMatFeeApplyDetailService;
import com.ejianc.business.zdsmaterial.material.service.IMatFeeApplyFileDetailService;
import com.ejianc.business.zdsmaterial.material.service.IMatFeeApplyService;
import com.ejianc.business.zdssupplier.material.api.IMatSupplierApi;
import com.ejianc.business.zdssupplier.material.vo.MatSupplierVO;
import com.ejianc.foundation.file.api.IAttachmentApi;
import com.ejianc.foundation.file.vo.AttachmentVO;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.vo.EmployeeVO;
import com.ejianc.foundation.share.api.IProjectPoolApi;
import com.ejianc.foundation.share.vo.ProjectPoolSetVO;
import com.ejianc.framework.core.kit.time.DateFormatUtil;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author CJ
 * @Description:
 * @date 2024/5/20 19:06
 */
@RestController
@RequestMapping("matFeeApply/erp")
public class MatFeeApplyErpController {

    Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IProjectPoolApi projectPoolApi;

    @Autowired
    private IEmployeeApi employeeApi;

    @Autowired
    private IAttachmentApi attachmentApi;

    @Autowired
    private IMatSupplierApi matSupplierApi;

    @Value("${common.env.base-host}")
    private String BASE_HOST;

    @Autowired
    private IMatFeeApplyService service;

    @Autowired
    private IMatFeeApplyDetailService detailService;

    @Autowired
    private IMatFeeApplyFileDetailService detailFileService;

    @PostMapping(value = "/pageList")
    public CommonResponse<JSONObject> pageSyncList(@RequestBody JSONObject param) {
        JSONObject resp = new JSONObject();

        logger.info("ERP查询采购费用申请参数：{}", JSONObject.toJSONString(param, SerializerFeature.PrettyFormat));
        Integer pageSize = null != param && null != param.getInteger("PageSize") ? param.getInteger("PageSize") : 10;
        Integer pageNum = null != param && null != param.getInteger("PageNum") ? param.getInteger("PageNum") : 1;
        String BeginDateTime = null != param && null != param.getString("BeginDateTime") ? param.getString("BeginDateTime") : null;
        String EndDateTime = null != param && null != param.getString("EndDateTime") ? param.getString("EndDateTime") : null;

        Map<String, Object> queryParam = new HashMap<>();
        if(StringUtils.isNotBlank(BeginDateTime)) {
            queryParam.put("beginDateTime", BeginDateTime);
        }
        if(StringUtils.isNotBlank(EndDateTime)) {
            queryParam.put("endDateTime", EndDateTime);
        }

        int count = service.pageCount(queryParam);
        resp.put("total", count);
        resp.put("pageSize", pageSize);
        resp.put("pageNum", pageNum);

        if (count == 0) {
            resp.put("records", new ArrayList<>());
            return CommonResponse.success("查询成功！", resp);
        }

        Integer startLine = pageNum - 1 < 0 ? pageSize : (pageNum - 1) * pageSize;
        queryParam.put("startLine", startLine);
        queryParam.put("pageSize", pageSize);

        List<JSONObject> pageList = service.pageList(queryParam);
        List<Long> projectIds = new ArrayList<>();
        List<Long> pIds = new ArrayList<>();
        List<Long> supplierIds = new ArrayList<>();
        List<String> empCodes = new ArrayList<>();
        pageList.stream().forEach(item -> {
            if (!projectIds.contains(item.getLong("projectId"))) {
                projectIds.add(item.getLong("projectId"));
            }
            if (!pIds.contains(item.getLong("YQL_SID"))) {
                pIds.add(item.getLong("YQL_SID"));
            }
            if (!supplierIds.contains(item.getLong("supplierId"))) {
                supplierIds.add(item.getLong("supplierId"));
            }
            if(StringUtils.isNotBlank(item.getString("ApprHumanCode")) && !empCodes.contains(item.getString("ApprHumanCode"))) {
                empCodes.add(item.getString("ApprHumanCode"));
            }
        });

        //查询项目信息
        CommonResponse<JSONArray> projectResp = projectPoolApi.queryProjectByIds(projectIds);
        if (!projectResp.isSuccess()) {
            logger.error("分包结算查询失败，根据项目Id列表-{}查询项目信息失败，{}", JSONObject.toJSONString(projectIds),
                    JSONObject.toJSONString(projectResp, SerializerFeature.PrettyFormat));
            return CommonResponse.error("查询失败，获取项目信息失败！");
        }

        Map<Long, String> projectSidMap = new HashMap<>();
        List<ProjectPoolSetVO> projectList = JSONArray.parseArray(JSONObject.toJSONString(projectResp.getData()), ProjectPoolSetVO.class);
        if (CollectionUtils.isNotEmpty(projectList)) {
            projectSidMap.putAll(projectList.stream().collect(Collectors.toMap(ProjectPoolSetVO::getId, ProjectPoolSetVO::getSourceId)));
        }

        //查询供应商信息
        Map<Long, MatSupplierVO> supplierMap = new HashMap<>();
        CommonResponse<List<MatSupplierVO>> supplierResp = matSupplierApi.getAllByIds(supplierIds);
        if (!supplierResp.isSuccess()) {
            logger.error("分包结算查询失败，根据供应商列表-{}查询人员信息失败，{}", JSONObject.toJSONString(supplierIds),
                    JSONObject.toJSONString(supplierResp, SerializerFeature.PrettyFormat));
            return CommonResponse.error("查询失败，获取供应商信息失败！");
        }
        supplierMap.putAll(supplierResp.getData().stream().collect(Collectors.toMap(MatSupplierVO::getId, Function.identity())));

        //查询人员信息
        Map<String, EmployeeVO> empMap = new HashMap<>();
        CommonResponse<List<EmployeeVO>> empResp = employeeApi.getAllByEmployeeCodes(empCodes);
        if(!empResp.isSuccess()) {
            logger.error("分包结算查询失败，根据人员工号列表-{}查询人员信息失败，{}", JSONObject.toJSONString(empCodes),
                    JSONObject.toJSONString(empResp, SerializerFeature.PrettyFormat));
            return CommonResponse.error("查询失败，获取人员信息失败！");
        }
        List<EmployeeVO> empList = empResp.getData();
        if(CollectionUtils.isNotEmpty(empList)) {
            empMap.putAll(empList.stream().collect(Collectors.toMap(EmployeeVO::getCode, Function.identity())));
        }

        //查询费用子表
        Map<Long, List<MatFeeApplyDetailEntity>> subDetailMap = detailService.getAllBySettleIds(pIds);

        //查询附件信息
        Map<Long, List<MatFeeApplyFileDetailEntity>> subFileMap = detailFileService.getAllBySettleIds(pIds);
        List<Long> fileIds = subFileMap.values().stream().flatMap(List::stream).map(MatFeeApplyFileDetailEntity::getAttachmentId).collect(Collectors.toList());
        CommonResponse<List<AttachmentVO>> attachResp = attachmentApi.queryAllByIds(fileIds);
        if(!attachResp.isSuccess()) {
            logger.error("根据sourceId列表-{}查询对应附件信息失败，", JSONObject.toJSONString(fileIds),
                    JSONObject.toJSONString(attachResp, SerializerFeature.PrettyFormat));
            return CommonResponse.error("查询失败，获取子表附件信息失败！");
        }

        List<AttachmentVO> fileData = attachResp.getData();
        Map<Long, AttachmentVO> fileMap = new HashMap<>();
        for (AttachmentVO vo: fileData){
            fileMap.put(vo.getId(), vo);
        }

        EmployeeVO emp = null;
        ProjectPoolSetVO project = null;
        MatSupplierVO supplier = null;
        AttachmentVO attach = null;
        for(JSONObject settle : pageList) {
            //获取项目信息
            settle.put("Account_Project_Sid", projectSidMap.get(settle.getLong("projectId")));
            settle.remove("projectId");
            //供应商信息
            supplier = supplierMap.get(settle.getLong("supplierId"));
            settle.put("Company_Sid", supplier.getThirdSourceId());
            settle.put("Company_Name", supplier.getName());
            settle.remove("supplierId");

            //获取审核人信息
            emp = empMap.get(settle.getString("ApprHumanCode"));
            settle.put("ApprHuman_sid", emp.getSourceId());
            settle.put("ApprHuman", emp.getName());

            //审核日期
            settle.put("ApprDate", DateFormatUtil.formatDate("yyyy-MM-dd", settle.getDate("ApprDate"))); //审核时间

            //子表信息
            JSONArray subDetailArr = new JSONArray();
            settle.put("SubDetailList", subDetailArr);
            if(null != subDetailMap.get(settle.getLong("YQL_SID"))) {
                JSONObject detailJson = null;
                for(MatFeeApplyDetailEntity detail : subDetailMap.get(settle.getLong("YQL_SID"))) {
                    detailJson = new JSONObject();
                    detailJson.put("ContractID", detail.getDetailContractCode()); //合同编码
                    detailJson.put("OrderCode", detail.getDetailOrderCode()); //订单编号
                    detailJson.put("Contract_Type", detail.getContractType()); //合同类型
                    detailJson.put("Contract_Flag", detail.getDetailPriceType()); //合同标识
                    detailJson.put("PaymentStyle", null != detail.getPaymentTypeId() ? PlanConstant.MAT_FEE_PATY_TYPE.get(detail.getPaymentTypeId().toString()) : ""); //合同标识
                    detailJson.put("ApplyMoney", detail.getApplyMny().toPlainString()); //本次申请金额
                    detailJson.put("ApplyPercentage", detail.getApplyScale().toPlainString()); //本次申请比例
                    detailJson.put("YQL_SID", detail.getId()); //本次申请比例

                    subDetailArr.add(detailJson);
                }
            }


            JSONArray subFileArr = new JSONArray();
            settle.put("ArchivesList", subFileArr);
            if(null != subFileMap.get(settle.getLong("YQL_SID"))) {
                JSONObject subF = null;
                for(MatFeeApplyFileDetailEntity scd : subFileMap.get(settle.getLong("YQL_SID"))) {
                    subF = new JSONObject();
                    attach = fileMap.get(scd.getAttachmentId());
                    if(null != attach) {
                        subF.put("Attach_Name", scd.getAttachmentName() + (scd.getAttachmentName().indexOf(".") < 0 ? attach.getFileName().substring(attach.getFileName().indexOf(".")) : "")); //附件名称
                        subF.put("Attach_Extension", attach.getFileName().substring(attach.getFileName().indexOf("."))); //附件扩展名
                        subF.put("Attach_Type", attach.getFileName().substring(attach.getFileName().indexOf(".")+1)); //附件类型
                        subF.put("AttachBase64", BASE_HOST + "filepreview/" + attach.getFilePath()); //附件类型
                        subF.put("YQL_SID", scd.getId()); //益企联主
                    }
                    subFileArr.add(subF);
                }
            }
        }

        resp.put("records", pageList);

        return CommonResponse.success("查询成功！", resp);
    }


}
